@@ -1,5 +1,5 @@
 /*  dctrl-tools - Debian control file inspection tools
-    Copyright © 2004, 2005, 2006, 2007 Antti-Juhani Kaijanaho
+    Copyright © 2004, 2005, 2006, 2007, 2008, 2009 Antti-Juhani Kaijanaho
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ static error_t parse_opt (int key, char * arg, struct argp_state * state)
 				*(flags++) = '\0';
 			}
 			struct key key;
-			key.field_inx = fieldtrie_insert(carg)->inx;
+			key.field_inx = fieldtrie_insert(s)->inx;
 			key.type = FT_STRING;
 			key.reverse = false;
 			for (char *p = flags; *p != '\0'; p++) {
@@ -84,21 +84,24 @@ static error_t parse_opt (int key, char * arg, struct argp_state * state)
 					key.type = FT_VERSION;
 					break;
 				default:
-					message(L_FATAL, _("invalid key flag"),
-						0);
+					message(L_FATAL, 0, 
+                                                _("invalid key flag"));
 					fail();
 				}
 			}
+                        debug("parse_opt: append key %d %d %d",
+                              key.field_inx, key.type, key.reverse);
 			keys_append(&args->keys, key);
 		}
-		break;
+                debug_message("parse_opt: k", 0);
+                break;
 	}
 	case 'l': 
 	{
 		int ll = str2loglevel(arg);
 		if (ll < 0)
 		{
-			message(L_FATAL, _("no such log level"), arg);
+			message(L_FATAL, 0, _("no such log level '%s'"), arg);
 			fail();
 		}
 		set_loglevel(ll);
@@ -114,7 +117,7 @@ static error_t parse_opt (int key, char * arg, struct argp_state * state)
 		{
 			char const * s;
 			if (args->num_fnames >= MAX_FNAMES) {
-				message(L_FATAL, _("too many file names"), 0);
+				message(L_FATAL, 0, _("too many file names"));
 				fail();
 			}
 			s = strdup(arg);
@@ -150,6 +153,8 @@ int main(int argc, char * argv[])
 	keys_init(&args.keys);
 	msg_set_progname(argv[0]);
 	argp_parse (&argp, argc, argv, ARGP_IN_ORDER, 0, &args);
+        
+        debug("number of keys: %zu", args.keys.nks);
 
 	if (args.keys.nks == 0) {
 		size_t inx = fieldtrie_insert("Package")->inx;
@@ -179,6 +184,7 @@ int main(int argc, char * argv[])
 		struct fsaf_read_rv r = get_whole_para(paras[i]);
 		fwrite(r.b, 1, r.len, stdout);
 		putchar('\n');
+		putchar('\n');
 	}
 	return 0;
 }
